============================================
 `xoutil.testing`:mod: -- Utilities testing
============================================

.. module:: xoutil.testing

Provides `sample data generators`__ for xoutil's data structures.

.. warning:: You must install ``xoutil[testing]`` in order to get extra
             dependencies.

.. versionadded:: 1.8.2


__ hypothesis_
.. _hypothesis: https://hypothesis.readthedocs.io/


.. toctree::
   :glob:

   testing/*
